Crate bc_envelope_pattern

Crate bc_envelope_pattern 

Modules

dcbor_integration
DCBor Pattern Integration

Structs

FormatPathsOpts
Options for formatting paths.
Interval
Represents an inclusive interval with a minimum value and an optional maximum value.
Quantifier
Defines how many times a pattern may or must match, with an interval and a reluctance.

Enums

DCBORPattern
Error
Errors that can occur during parsing of Envelope patterns.
PathElementFormat
A builder that provides formatting options for each path element.
Pattern
The main pattern type used for matching envelopes.
Reluctance
Reluctance for quantifiers.

Functions

format_path
Format each path element on its own line, each line successively indented by 4 spaces.
format_path_opt
Format each path element on its own line, each line successively indented by 4 spaces. Options can be provided to customize the formatting.
format_paths
Format multiple paths with default options.
format_paths_opt
Format multiple paths with custom formatting options.
format_paths_with_captures
format_paths_with_captures_opt
Format multiple paths with captures in a structured way. Captures come first, sorted lexicographically by name, with their name prefixed by ‘@’. Regular paths follow after all captures.

Type Aliases

Path
A vector of envelopes that match a pattern, starting from the root of the envelope.
Result
A Result type specialized for envelope pattern parsing.