DCBORPattern

Enum DCBORPattern 

pub enum DCBORPattern {
    Value(ValuePattern),
    Structure(StructurePattern),
    Meta(MetaPattern),
}

Variants

Implementations

Source

impl Pattern

pub fn parse(input: &str) -> Result<Pattern, Error>

Parse a pattern expression from a string.

pub fn parse_partial(input: &str) -> Result<(Pattern, usize), Error>

Parses a pattern from the beginning of a string and returns both the parsed Pattern and the number of bytes consumed.

Unlike parse(), this function succeeds even if additional characters follow the first pattern. The returned index points to the first unparsed character after the pattern.

Example
let (pattern, consumed) = Pattern::parse_partial("true rest").unwrap();
assert_eq!(pattern, Pattern::bool(true));
assert_eq!(consumed, 5); // "true ".len() - includes whitespace
Source

impl Pattern

pub fn any_bool() -> Pattern

Creates a pattern that matches any boolean value.

pub fn bool(value: bool) -> Pattern

Creates a pattern that matches a specific boolean value.

pub fn any_number() -> Pattern

Creates a pattern that matches any number value.

pub fn number<T>(value: T) -> Pattern
where T: Into<f64>,

Creates a pattern that matches a specific number value.

pub fn number_range<A>(range: RangeInclusive<A>) -> Pattern
where A: Into<f64> + Copy,

Creates a pattern that matches numbers within a range.

pub fn number_greater_than<T>(value: T) -> Pattern
where T: Into<f64>,

Creates a pattern that matches numbers greater than the specified value.

pub fn number_greater_than_or_equal<T>(value: T) -> Pattern
where T: Into<f64>,

Creates a pattern that matches numbers greater than or equal to the specified value.

pub fn number_less_than<T>(value: T) -> Pattern
where T: Into<f64>,

Creates a pattern that matches numbers less than the specified value.

pub fn number_less_than_or_equal<T>(value: T) -> Pattern
where T: Into<f64>,

Creates a pattern that matches numbers less than or equal to the specified value.

pub fn number_nan() -> Pattern

Creates a pattern that matches NaN values.

pub fn number_infinity() -> Pattern

Creates a pattern that matches positive infinity values.

pub fn number_neg_infinity() -> Pattern

Creates a pattern that matches negative infinity values.

pub fn any_text() -> Pattern

Creates a pattern that matches any text value.

pub fn text<T>(value: T) -> Pattern
where T: Into<String>,

Creates a pattern that matches a specific text value.

pub fn text_regex(regex: Regex) -> Pattern

Creates a pattern that matches text using a regex.

pub fn any_byte_string() -> Pattern

Creates a pattern that matches any byte string value.

pub fn byte_string(value: impl AsRef<[u8]>) -> Pattern

Creates a pattern that matches a specific byte string value.

pub fn byte_string_regex(regex: Regex) -> Pattern

Creates a pattern that matches byte strings using a binary regex.

pub fn any_date() -> Pattern

Creates a pattern that matches any date value.

pub fn date(date: Date) -> Pattern

Creates a pattern that matches a specific date value.

pub fn date_range(range: RangeInclusive<Date>) -> Pattern

Creates a pattern that matches dates within a range (inclusive).

pub fn date_earliest(date: Date) -> Pattern

Creates a pattern that matches dates that are on or after the specified date.

pub fn date_latest(date: Date) -> Pattern

Creates a pattern that matches dates that are on or before the specified date.

pub fn date_iso8601(iso_string: impl Into<String>) -> Pattern

Creates a pattern that matches a date by its ISO-8601 string representation.

pub fn date_regex(regex: Regex) -> Pattern

Creates a pattern that matches dates whose ISO-8601 string representation matches the given regex pattern.

pub fn null() -> Pattern

Creates a pattern that matches null values.

pub fn any_known_value() -> Pattern

Creates a pattern that matches any known value.

pub fn known_value(value: KnownValue) -> Pattern

Creates a pattern that matches a specific known value.

pub fn known_value_named(name: impl Into<String>) -> Pattern

Creates a pattern that matches a known value by name.

pub fn known_value_regex(regex: Regex) -> Pattern

Creates a pattern that matches known values using a regex on their names.

pub fn any_digest() -> Pattern

Creates a pattern that matches any digest value.

pub fn digest(digest: Digest) -> Pattern

Creates a pattern that matches a specific digest.

pub fn digest_prefix(prefix: impl AsRef<[u8]>) -> Pattern

Creates a pattern that matches digests with the specified prefix.

pub fn digest_binary_regex(regex: Regex) -> Pattern

Creates a pattern that matches digests using a binary regex.

pub fn any() -> Pattern

Creates a pattern that always matches any CBOR value.

pub fn and(patterns: Vec<Pattern>) -> Pattern

Creates a pattern that matches if all contained patterns match.

pub fn or(patterns: Vec<Pattern>) -> Pattern

Creates a pattern that matches if any contained pattern matches.

pub fn not_matching(pattern: Pattern) -> Pattern

Creates a pattern that matches if the inner pattern does not match.

pub fn capture(name: impl AsRef<str>, pattern: Pattern) -> Pattern

Creates a pattern that captures matches with the given name.

pub fn search(pattern: Pattern) -> Pattern

Creates a search pattern that recursively searches the entire dCBOR tree.

pub fn repeat(pattern: Pattern, quantifier: Quantifier) -> Pattern

Creates a pattern that matches with repetition using a quantifier.

pub fn group(pattern: Pattern) -> Pattern

Creates a pattern that wraps another pattern (matches exactly once).

pub fn sequence(patterns: Vec<Pattern>) -> Pattern

Creates a sequence pattern that matches patterns in order.

pub fn any_array() -> Pattern

Creates a pattern that matches any array.

pub fn any_map() -> Pattern

Creates a pattern that matches any map.

Source

impl Pattern

pub fn any_tagged() -> Pattern

Creates a pattern that matches any tagged value.

pub fn tagged(tag: impl Into<Tag>, pattern: Pattern) -> Pattern

Creates a pattern that matches a tagged item with content pattern.

pub fn tagged_name(name: impl Into<String>, pattern: Pattern) -> Pattern

Creates a pattern that matches a tagged item with content pattern and a specific tag name.

pub fn tagged_regex(regex: Regex, pattern: Pattern) -> Pattern

Creates a pattern that matches a tagged item with content pattern and a regex for the tag name.