Crate bc_envelope_pattern

Structs

FormatPathsOpts
Options for formatting paths.
Interval
Represents an inclusive interval with a minimum value and an optional maximum value.
Quantifier
Defines how many times a pattern may or must match, with an interval and a reluctance.

Enums

Error
Errors that can occur during parsing of Envelope patterns.
PathElementFormat
A builder that provides formatting options for each path element.
Pattern
The main pattern type used for matching envelopes.
Reluctance
Reluctance for quantifiers.

Functions

format_path
Format each path element on its own line, each line successively indented by 4 spaces.
format_path_opt
Format each path element on its own line, each line successively indented by 4 spaces. Options can be provided to customize the formatting.
format_paths
Format multiple paths with default options.
format_paths_opt
Format multiple paths with custom formatting options.

Type Aliases

Path
A sequence of envelopes that match a pattern, starting from the root of the envelope.
Result
A Result type specialized for envelope pattern parsing.