Enum Pattern

pub enum Pattern {
    Leaf(LeafPattern),
    Structure(StructurePattern),
    Meta(MetaPattern),
}
The main pattern type used for matching envelopes.

Variants



Leaf(LeafPattern)

Leaf patterns for matching CBOR values.



Structure(StructurePattern)

Structure patterns for matching envelope elements.



Meta(MetaPattern)

Meta-patterns for combining and modifying other patterns.

Implementations

Source

impl Pattern

pub fn parse(input: impl AsRef<str>) -> Result<Pattern>

Parse a pattern expression.

Source

impl Pattern

pub fn any_leaf() -> Self

Creates a new Pattern that matches any leaf.

Source

impl Pattern

pub fn any_cbor() -> Self

Creates a new Pattern that matches any CBOR value.

pub fn cbor(cbor: impl CBOREncodable) -> Self

Creates a new Pattern that matches a specific CBOR value.

Source

impl Pattern

pub fn any_bool() -> Self

Creates a new Pattern that matches any boolean value.

pub fn bool(b: bool) -> Self

Creates a new Pattern that matches a specific boolean value.

Source

impl Pattern

pub fn any_text() -> Self

Creates a new Pattern that matches any text value.

pub fn text<T: Into<String>>(value: T) -> Self

Creates a new Pattern that matches a specific text value.

pub fn text_regex(regex: Regex) -> Self

Creates a new Pattern that matches text values that match the given regular expression.

Source

impl Pattern

pub fn any_date() -> Self

Creates a new Pattern that matches any Date (CBOR tag 1) value.

pub fn date(date: Date) -> Self

Creates a new Pattern that matches a specific Date (CBOR tag 1) value.

pub fn date_range(range: RangeInclusive<Date>) -> Self

Creates a new Pattern that matches Date (CBOR tag 1) values within a specified range (inclusive).

pub fn date_earliest(date: Date) -> Self

Creates a new Pattern that matches Date (CBOR tag 1) values that are on or after the specified date.

pub fn date_latest(date: Date) -> Self

Creates a new Pattern that matches Date (CBOR tag 1) values that are on or before the specified date.

pub fn date_iso8601(iso_string: impl Into<String>) -> Self

Creates a new Pattern that matches Date (CBOR tag 1) values by their ISO-8601 string representation.

pub fn date_regex(regex: Regex) -> Self

Creates a new Pattern that matches Date (CBOR tag 1) values whose ISO-8601 string representation matches the given regular expression.

Source

impl Pattern

pub fn any_number() -> Self

Creates a new Pattern that matches any number value.

pub fn number<T: Into<f64>>(value: T) -> Self

Creates a new Pattern that matches a specific number value.

pub fn number_range<A: Into<f64> + Copy>(range: RangeInclusive<A>) -> Self

Creates a new Pattern that matches number values within a specified range (inclusive).

pub fn number_greater_than<T: Into<f64>>(value: T) -> Self

Creates a new Pattern that matches number values that are greater than the specified value.

pub fn number_greater_than_or_equal<T: Into<f64>>(value: T) -> Self

Creates a new Pattern that matches number values that are greater than or equal to the specified value.

pub fn number_less_than<T: Into<f64>>(value: T) -> Self

Creates a new Pattern that matches number values that are less than the specified value.

pub fn number_less_than_or_equal<T: Into<f64>>(value: T) -> Self

Creates a new Pattern that matches number values that are less than or equal to the specified value.

pub fn number_nan() -> Self

Creates a new Pattern that matches number values that are NaN (Not a Number).

Source

impl Pattern

pub fn any_byte_string() -> Self

Creates a new Pattern that matches any byte string value.

pub fn byte_string(value: impl AsRef<[u8]>) -> Self

Creates a new Pattern that matches a specific byte string value.

pub fn byte_string_binary_regex(regex: Regex) -> Self

Creates a new Pattern that matches byte string values that match the given binary regular expression.

Source

impl Pattern

pub fn any_known_value() -> Self

pub fn known_value(value: KnownValue) -> Self

pub fn known_value_named<T: Into<String>>(name: T) -> Self

pub fn known_value_regex(regex: Regex) -> Self

pub fn unit() -> Self

Source

impl Pattern

pub fn any_array() -> Self

pub fn array_with_range(interval: impl RangeBounds<usize>) -> Self

pub fn array_with_count(count: usize) -> Self

Source

impl Pattern

pub fn any_map() -> Self

pub fn map_with_range(interval: impl RangeBounds<usize>) -> Self

pub fn map_with_count(count: usize) -> Self

Source

impl Pattern

pub fn null() -> Self

Source

impl Pattern

pub fn any_tag() -> Self

pub fn tagged(tag: Tag) -> Self

pub fn tagged_with_value(value: u64) -> Self

pub fn tagged_with_name(name: impl Into<String>) -> Self

pub fn tagged_with_regex(regex: Regex) -> Self

Source

impl Pattern

pub fn any_assertion() -> Self

pub fn assertion_with_predicate(pattern: Pattern) -> Self

pub fn assertion_with_object(pattern: Pattern) -> Self

Source

impl Pattern

pub fn any_subject() -> Self

pub fn subject(pattern: Pattern) -> Self

Source

impl Pattern

pub fn any_predicate() -> Self

pub fn predicate(pattern: Pattern) -> Self

pub fn any_object() -> Self

pub fn object(pattern: Pattern) -> Self

Source

impl Pattern

pub fn digest(digest: Digest) -> Self

pub fn digest_prefix(prefix: impl AsRef<[u8]>) -> Self

pub fn digest_binary_regex(regex: Regex) -> Self

pub fn any_node() -> Self

pub fn node_with_assertions_range(range: impl RangeBounds<usize>) -> Self

pub fn node_with_assertions_count(count: usize) -> Self

pub fn obscured() -> Self

pub fn elided() -> Self

pub fn encrypted() -> Self

pub fn compressed() -> Self

Source

impl Pattern

pub fn any() -> Self

Creates a new Pattern that matches any element.

pub fn none() -> Self

Creates a new Pattern that never matches any element.

Source

impl Pattern

pub fn and(patterns: Vec<Pattern>) -> Self

Creates a new Pattern that only matches if all specified patterns match.

pub fn or(patterns: Vec<Pattern>) -> Self

Creates a new Pattern that matches if at least one of the specified patterns matches.

Source

impl Pattern

pub fn sequence(patterns: Vec<Pattern>) -> Self

Creates a new Pattern that matches a sequence of patterns in order.

Source

impl Pattern

pub fn search(pattern: Pattern) -> Self

Creates a new Pattern that searches for a specific pattern within the envelope. Useful for finding patterns that may not be at the root of the envelope.

Source

impl Pattern

pub fn not_matching(pattern: Pattern) -> Self

Creates a new Pattern that negates another pattern; matches if the specified pattern does not match.

Source

impl Pattern

pub fn repeat( pattern: Pattern, interval: impl RangeBounds<usize>, reluctance: Reluctance, ) -> Self

Creates a new Pattern that will match a pattern repeated a number of times according to the specified range and greediness.

In regex terms:

RangeQuantifier
..*
1..+
0..=1?
min..=max{min,max}
min..{min,}
..=max{0,max}
n..=n{n}
pub fn group(pattern: Pattern) -> Self

Source

impl Pattern

pub fn capture(name: impl AsRef<str>, pattern: Pattern) -> Self

Creates a new Pattern that will capture a pattern match with a name.

Source

impl Pattern

pub fn wrapped() -> Self

Creates a new Pattern that matches any wrapped envelope without descending. Renamed from wrapped() to break tests so they can be fixed.

pub fn unwrap_matching(pattern: Pattern) -> Self

Creates a new Pattern that matches a wrapped envelope and also matches on its unwrapped content.

pub fn unwrap() -> Self

Creates a new Pattern that matches any wrapped envelope and descends into it.